# frozen_string_literal: true

require 'distributed_press'

Jekyll::Hooks.register :site, :post_write, priority: :low do |site|
  next unless ENV['JEKYLL_ENV'] == 'production'
  if site.config['locales']
    next unless site.config['locale'] == site.config['locales'].last
  end

  hostname   = ENV['DISTRIBUTED_PRESS_PROJECT_DOMAIN']
  hostname ||= site.config['hostname']
  hostname ||= URI(site.config['url']).hostname

  raise URI::Error unless hostname

  Jekyll.logger.info 'Distributed Press:', 'Publishing website'

  distributed_press = DistributedPress.new project_domain: hostname
  distributed_press.configure && distributed_press.publish(site.dest)

  Jekyll.logger.info 'Distributed Press:', 'Published!'
rescue URI::Error
  Jekyll.logger.warn 'Distributed Press:', '`hostname` or `url` keys missing on _config.yml, skipping publication.'
end
